************************************************************************************
***Table 2A: Elite capture in historical programs **********************************
************************************************************************************

clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000


*********************************
*1. Inputting data***************
*********************************

*** Benefits ***
use "$codeddata/Baseline/historical_getbenefit.dta", clear
merge 1:1 hhid using "$originaldata/new crosswalk.dta"
keep if _merge==1|_merge==3
drop _merge

*** Elite ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge





*********************************
*2. Coding***********************
*********************************

*** Coding PPLS status ***
gen ppls08_1=(klas_ppls=="HM" | klas_ppls=="M" | klas_ppls=="SM")
gen ppls08_2=(klas_ppls=="M" | klas_ppls=="SM")
gen ppls08_3=(klas_ppls=="SM")
la var ppls08_1 "HM, M and SM"
la var ppls08_2 "M and SM"
la var ppls08_3 "SM"







*********************************
*3. Analysis*********************
*********************************


* Actual benefit receipt

label var elite_related_1 "Elite"
label var logconsumption "Log Consumption"

areg getbenefit_BLT08 elite_related_1 logconsumption, ab(kecagroup) cl(hhea)
qui summ getbenefit_BLT08 if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1A.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("BLT08") replace
 
areg getbenefit_askeskin elite_related_1 logconsumption, ab(kecagroup) cl(hhea)
qui summ getbenefit_askeskin if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1A.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Jamkesmas") append

areg getbenefit_raskin elite_related_1 logconsumption, ab(kecagroup) cl(hhea)
qui summ getbenefit_raskin if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Appendix Table 1A.doc", label nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Raskin") append

