***************************************************************
***Part 6 of Hybrid Analysis Plan: Comparing Historical Data***
***************************************************************

clear
clear matrix
clear mata

set more off
set mem 256m

set sortseed 10000


*get survey year
use "$originaldata/Baseline/hh_cov.dta",clear
gen survey_year = hhivwyy1
keep hhid survey_year
tempfile survey
sa `survey', replace

*coding raskin and askeskin beneficiaries: still receiving the program or last received in the same year*
use "$originaldata/Baseline/hh_ksr1.dta",clear
merge m:1 hhid using `survey'
drop if _merge==2
drop _merge

gen temp1=(ksr1type=="a" & ksr01ax==1)
gen temp2=(ksr1type=="b" & ksr01ax==1)
gen temp3=(ksr1type=="c" & ksr01==1)
replace temp1 = 1 if ksr1type=="a" & ksr01ax==3 & ksr01a==survey_year
replace temp2 = 1 if ksr1type=="b" & ksr01ax==3 & ksr01a==survey_year

bys hhid : egen getbenefit_askeskin=max(temp1)
bys hhid : egen getbenefit_raskin=max(temp2)
bys hhid : egen getbenefit_PKPS=max(temp3)

duplicates drop hhid, force
keep hhid getbenefit_askeskin getbenefit_raskin getbenefit_PKPS

tempfile a
sa `a', replace

use "$originaldata/Baseline/hh_ksr2.dta",clear
gen temp1=(ksr2type=="a" & ksr02==1)
gen temp2=(ksr2type=="b" & ksr02==1)
bys hhid : egen getbenefit_BLT05=max(temp1)
bys hhid : egen getbenefit_BLT08=max(temp2)

duplicates drop hhid, force
keep  hhid getbenefit_BLT05 getbenefit_BLT08
tempfile b
sa `b', replace

use "$codeddata/Baseline/matched_baseline_hybrid.dta", replace
merge 1:1 hhid using `a'
assert _merge!=1
keep if _merge==3
drop _merge
merge 1:1 hhid using `b'

drop if _merge==2
drop _merge

***only 2616 observations in `b'***
replace getbenefit_BLT05=0 if getbenefit_PKPS==0
replace getbenefit_BLT08=0 if getbenefit_PKPS==0
replace getbenefit_PKPS=. if getbenefit_BLT05==0&getbenefit_BLT08==0&getbenefit_PKPS==1
replace getbenefit_BLT05=. if getbenefit_PKPS==.
replace getbenefit_BLT08=. if getbenefit_PKPS==.

keep hhid hhea kecagroup logconsumption getbenefit_askeskin getbenefit_raskin getbenefit_BLT05 getbenefit_BLT08

sa "$codeddata/Baseline/historical_getbenefit.dta", replace



