***************************************
** Coding Part V of the Analysis Plan: hybrid
***************************************

clear
clear matrix
clear mata

set more off
set mem 256m

set sortseed 10000

*****************
*baseline sample*
*****************

use "$codeddata/Baseline/matched_baseline_hybrid.dta",clear

/*generate errors*/

/*First way to define poverty line(Let's define the poveryt line as the 16th percentile in the SUSETI
in per capita expenditrue in the baseline, by district. Let's define"very poor" as less than 0.8 * the poverty line.)*/

gen excl_error=0 if  verypoor_povertyline1==1 & getbenefit==1
replace excl_error=1 if getbenefit==0 & verypoor_povertyline1==1

gen incl_error=0 if  verypoor_povertyline1==0 & getbenefit==0
replace incl_error=1 if  verypoor_povertyline1==0 & getbenefit==1

gen mistarget= excl_error
replace mistarget= incl_error if mistarget==.

/*heterogeneity*/
gen urban = (clas==1)
gen hybrid_urban=hybrid*urban

gen hybrid_povertydensity=hybrid*povertydensity

tab prov
gen java=(prov=="33")
gen hybrid_java=hybrid*java

tempfile baseline
save `baseline',replace

keep hhea povertydensity hybrid_povertydensity
duplicates drop hhea povertydensity hybrid_povertydensity,force	/*keep one value for each village. 400 obs*/
tempfile density
save `density',replace

/*counterfactual*/
use `baseline',clear
gen getbenefit_cf=0

//use PMT cutoff: beneficiaries if showup and pmt<real cutoff line in numbers. 

replace getbenefit_cf=1 if pcexppred<povertyline2 & showup==1

bys maintreatment: egen rank_pmtscore=rank (PMTSCORE) if getbenefit_cf==1,track
gen getbenefit_pmt_const=0
replace getbenefit_pmt_const=1 if rank_pmtscore<78 /*number of actual beneficiaries in the PMT group*/

gen excl_error_pmt_const=0 if  verypoor_povertyline1==1 & getbenefit_pmt_const==1
replace excl_error_pmt_const=1 if getbenefit_pmt_const==0 & verypoor_povertyline1==1

gen incl_error_pmt_const=0 if  verypoor_povertyline1==0 & getbenefit_pmt_const==0
replace incl_error_pmt_const=1 if  verypoor_povertyline1==0 & getbenefit_pmt_const==1

gen mistarget_pmt_const= excl_error_pmt_const
replace mistarget_pmt_const= incl_error_pmt_const if mistarget_pmt_const==.

save "$codeddata/Baseline/coded_baseline_partV_hybrid",replace

*********************
*poorest five sample*
*********************

use "$originaldata/Baseline/matched_full_hybrid.dta",clear 
bys hhea: egen rank_votes=rank (count_poor5),field			

/*Exclusion*/
gen excl_error_N1=0 if  rank_votes<2  & getbenefit==1			
replace excl_error_N1=1 if getbenefit==0 & rank_votes<2

gen excl_error_N2=0 if  rank_votes<3 & getbenefit==1
replace excl_error_N2=1 if getbenefit==0 & rank_votes<3

gen excl_error_N3=0 if  rank_votes<4 & getbenefit==1
replace excl_error_N3=1 if getbenefit==0 & rank_votes<4

gen excl_error_N4=0 if  rank_votes<5 & getbenefit==1
replace excl_error_N4=1 if getbenefit==0 & rank_votes<5

gen excl_error_N5=0 if  rank_votes<6 & getbenefit==1
replace excl_error_N5=1 if getbenefit==0 & rank_votes<6

/*heterogeneity*/
gen urban = (clas==1)
gen hybrid_urban=hybrid*urban

merge m:1 hhea using `density'
keep if _merge==3
drop _merge 

tempfile full
save `full',replace

use "$originaldata/Others/wilcah",clear
gen prov=substr(id,1,2)
rename wilcah hhea
destring id,replace
merge 1:m hhea using `full'
assert _merge==1|_merge==3
drop if _merge==1	/*drop hybrid villages for now*/
drop _merge
gen java=(prov=="33")
codebook java
gen hybrid_java=hybrid*java

** save final data set
save "$codeddata/Baseline/coded_poor5_partV_hybrid",replace


